# stattotex-python

A simple function for automatically updating LaTeX documents with numbers from Python.

Python port of [isapollnik/stattotex](https://github.com/isapollnik/stattotex).

## Usage

Note that you may not include underscores in `number_name`.
